tomlkit: Style preserving TOML library
======================================

Description
-----------

Style preserving TOML library

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/tomlkit/

